From e4e38e02cfe626ffeda26b1d4a08df7a6cd3997d Mon Sep 17 00:00:00 2001
From: thomascube <thomas@roundcube.net>
Date: Wed, 02 Feb 2011 14:41:41 -0500
Subject: [PATCH] Fix inconsistency in de_DE localization (#1487749)

---
 program/include/rcube_mdb2.php |  134 +++++++++++++++++++++++---------------------
 1 files changed, 71 insertions(+), 63 deletions(-)

diff --git a/program/include/rcube_mdb2.php b/program/include/rcube_mdb2.php
index dda64b7..c56a86e 100644
--- a/program/include/rcube_mdb2.php
+++ b/program/include/rcube_mdb2.php
@@ -4,8 +4,8 @@
  +-----------------------------------------------------------------------+
  | program/include/rcube_mdb2.php                                        |
  |                                                                       |
- | This file is part of the RoundCube Webmail client                     |
- | Copyright (C) 2005-2009, RoundCube Dev. - Switzerland                 |
+ | This file is part of the Roundcube Webmail client                     |
+ | Copyright (C) 2005-2009, The Roundcube Dev Team                       |
  | Licensed under the GNU GPL                                            |
  |                                                                       |
  | PURPOSE:                                                              |
@@ -30,7 +30,7 @@
  * @author     David Saez Padros <david@ols.es>
  * @author     Thomas Bruederli <roundcube@gmail.com>
  * @author     Lukas Kahwe Smith <smith@pooteeweet.org>
- * @version    1.16
+ * @version    1.17
  * @link       http://pear.php.net/package/MDB2
  */
 class rcube_mdb2
@@ -52,8 +52,8 @@
     /**
      * Object constructor
      *
-     * @param  string  DSN for read/write operations
-     * @param  string  Optional DSN for read only operations
+     * @param  string $db_dsnw DSN for read/write operations
+     * @param  string $db_dsnr Optional DSN for read only operations
      */
     function __construct($db_dsnw, $db_dsnr='', $pconn=false)
     {
@@ -63,7 +63,7 @@
         $this->db_dsnw = $db_dsnw;
         $this->db_dsnr = $db_dsnr;
         $this->db_pconn = $pconn;
-    
+
         $dsn_array = MDB2::parseDSN($db_dsnw);
         $this->db_provider = $dsn_array['phptype'];
     }
@@ -72,8 +72,8 @@
     /**
      * Connect to specific database
      *
-     * @param  string  DSN for DB connections
-     * @return object  PEAR database handle
+     * @param  string $dsn  DSN for DB connections
+     * @return MDB2 PEAR database handle
      * @access private
      */
     private function dsn_connect($dsn)
@@ -84,7 +84,7 @@
             'emulate_prepared' => $this->debug_mode,
             'debug'            => $this->debug_mode,
             'debug_handler'    => 'mdb2_debug_handler',
-            'portability'      => MDB2_PORTABILITY_ALL ^ MDB2_PORTABILITY_EMPTY_TO_null);
+            'portability'      => MDB2_PORTABILITY_ALL ^ MDB2_PORTABILITY_EMPTY_TO_NULL);
 
         if ($this->db_provider == 'pgsql') {
             $db_options['disable_smart_seqname'] = true;
@@ -96,7 +96,7 @@
         if (MDB2::isError($dbh)) {
             $this->db_error = true;
             $this->db_error_msg = $dbh->getMessage();
-      
+
             raise_error(array('code' => 500, 'type' => 'db',
                 'line' => __LINE__, 'file' => __FILE__,
                 'message' => $dbh->getUserInfo()), true, false);
@@ -116,22 +116,22 @@
     /**
      * Connect to appropiate database depending on the operation
      *
-     * @param  string  Connection mode (r|w)
+     * @param  string $mode Connection mode (r|w)
      * @access public
      */
     function db_connect($mode)
     {
-        $this->db_mode = $mode;
-
         // Already connected
         if ($this->db_connected) {
-            // no replication, current connection is ok
-            if ($this->db_dsnw == $this->db_dsnr)
-                return;
-
-            // connected to master, current connection is ok
+            // connected to read-write db, current connection is ok
             if ($this->db_mode == 'w')
                 return;
+
+            // no replication, current connection is ok for read and write
+            if (empty($this->db_dsnr) || $this->db_dsnw == $this->db_dsnr) {
+                $this->db_mode = 'w';
+                return;
+            }
 
             // Same mode, current connection is ok
             if ($this->db_mode == $mode)
@@ -141,14 +141,15 @@
         $dsn = ($mode == 'r') ? $this->db_dsnr : $this->db_dsnw;
 
         $this->db_handle = $this->dsn_connect($dsn);
-        $this->db_connected = true;
+        $this->db_connected = !PEAR::isError($this->db_handle);
+        $this->db_mode = $mode;
     }
 
 
     /**
      * Activate/deactivate debug mode
      *
-     * @param boolean True if SQL queries should be logged
+     * @param boolean $dbg True if SQL queries should be logged
      * @access public
      */
     function set_debug($dbg = true)
@@ -195,11 +196,12 @@
      */
     function query()
     {
-        if (!$this->is_connected())
-            return null;
-    
         $params = func_get_args();
         $query = array_shift($params);
+
+        // Support one argument of type array, instead of n arguments
+        if (count($params) == 1 && is_array($params[0]))
+            $params = $params[0];
 
         return $this->_query($query, 0, 0, $params);
     }
@@ -229,10 +231,10 @@
     /**
      * Execute a SQL query with limits
      *
      * @param  string  SQL query to execute
      * @param  number  Offset for LIMIT statement
      * @param  number  Number of rows for LIMIT statement
      * @param  array   Values to be inserted in query
      * @return number  Query handle identifier
      * @access private
      */
@@ -242,6 +244,10 @@
         $mode = (strtolower(substr(trim($query),0,6)) == 'select') ? 'r' : 'w';
 
         $this->db_connect($mode);
+
+        // check connection before proceeding
+        if (!$this->is_connected())
+            return null;
 
         if ($this->db_provider == 'sqlite')
             $this->_sqlite_prepare();
@@ -277,7 +283,7 @@
      * Get number of rows for a SQL query
      * If no query handle is specified, the last query will be taken as reference
      *
-     * @param  number  Optional query handle identifier
+     * @param  number $res_id  Optional query handle identifier
      * @return mixed   Number of rows or false on failure
      * @access public
      */
@@ -296,7 +302,7 @@
     /**
      * Get number of affected rows for the last query
      *
-     * @param  number  Optional query handle identifier
+     * @param  number $res_id Optional query handle identifier
      * @return mixed   Number of rows or false on failure
      * @access public
      */
@@ -313,7 +319,7 @@
      * Get last inserted record ID
      * For Postgres databases, a sequence name is required
      *
-     * @param  string  Table name (to find the incremented sequence)
+     * @param  string $table  Table name (to find the incremented sequence)
      * @return mixed   ID or false on failure
      * @access public
      */
@@ -332,7 +338,7 @@
         }
 
         $id = $this->db_handle->lastInsertID($table);
-    
+
         return $this->db_handle->isError($id) ? null : $id;
     }
 
@@ -341,7 +347,7 @@
      * Get an associative array for one row
      * If no query handle is specified, the last query will be taken as reference
      *
-     * @param  number  Optional query handle identifier
+     * @param  number $res_id Optional query handle identifier
      * @return mixed   Array with col values or false on failure
      * @access public
      */
@@ -356,7 +362,7 @@
      * Get an index array for one row
      * If no query handle is specified, the last query will be taken as reference
      *
-     * @param  number  Optional query handle identifier
+     * @param  number $res_id  Optional query handle identifier
      * @return mixed   Array with col values or false on failure
      * @access public
      */
@@ -370,8 +376,8 @@
     /**
      * Get col values for a result row
      *
-     * @param  object  Query result handle
-     * @param  number  Fetch mode identifier
+     * @param  MDB2_Result_Common Query $result result handle
+     * @param  number                   $mode   Fetch mode identifier
      * @return mixed   Array with col values or false on failure
      * @access private
      */
@@ -409,8 +415,8 @@
     /**
      * Formats input so it can be safely used in a query
      *
-     * @param  mixed   Value to quote
-     * @param  string  Type of data
+     * @param  mixed  $input  Value to quote
+     * @param  string $type   Type of data
      * @return string  Quoted/converted string for use in query
      * @access public
      */
@@ -431,7 +437,7 @@
     /**
      * Quotes a string so it can be safely used as a table or column name
      *
-     * @param  string  Value to quote
+     * @param  string $str Value to quote
      * @return string  Quoted string for use in query
      * @deprecated     Replaced by rcube_MDB2::quote_identifier
      * @see            rcube_mdb2::quote_identifier
@@ -446,7 +452,7 @@
     /**
      * Quotes a string so it can be safely used as a table or column name
      *
-     * @param  string  Value to quote
+     * @param  string $str Value to quote
      * @return string  Quoted string for use in query
      * @access public
      */
@@ -462,7 +468,7 @@
     /**
      * Escapes a string
      *
-     * @param  string  The string to be escaped
+     * @param  string $str The string to be escaped
      * @return string  The escaped string
      * @access public
      * @since  0.1.1
@@ -471,7 +477,7 @@
     {
         if (!$this->db_handle)
             $this->db_connect('r');
-   
+
         return $this->db_handle->escape($str);
     }
 
@@ -498,8 +504,8 @@
     /**
      * Return list of elements for use with SQL's IN clause
      *
-     * @param  array  Input array
-     * @param  string Type of data
+     * @param  array  $arr  Input array
+     * @param  string $type Type of data
      * @return string Comma-separated list of quoted values for use in query
      * @access public
      */
@@ -507,7 +513,7 @@
     {
         if (!is_array($arr))
             return $this->quote($arr, $type);
-    
+
         foreach ($arr as $idx => $item)
             $arr[$idx] = $this->quote($item, $type);
 
@@ -518,7 +524,7 @@
     /**
      * Return SQL statement to convert a field value into a unix timestamp
      *
-     * @param  string  Field name
+     * @param  string $field Field name
      * @return string  SQL statement to use in query
      * @access public
      */
@@ -530,7 +536,7 @@
 
             case 'mssql':
             case 'sqlsrv':
-	            return "DATEDIFF(second, '19700101', $field) + DATEDIFF(second, GETDATE(), GETUTCDATE())";
+                return "DATEDIFF(second, '19700101', $field) + DATEDIFF(second, GETDATE(), GETUTCDATE())";
 
             default:
                 return "UNIX_TIMESTAMP($field)";
@@ -541,7 +547,7 @@
     /**
      * Return SQL statement to convert from a unix timestamp
      *
-     * @param  string  Field name
+     * @param  string $timestamp Field name
      * @return string  SQL statement to use in query
      * @access public
      */
@@ -562,8 +568,8 @@
     /**
      * Return SQL statement for case insensitive LIKE
      *
-     * @param  string  Field name
-     * @param  string  Search value
+     * @param  string $column  Field name
+     * @param  string $value   Search value
      * @return string  SQL statement to use in query
      * @access public
      */
@@ -582,7 +588,7 @@
     /**
      * Encodes non-UTF-8 characters in string/array/object (recursive)
      *
-     * @param  mixed  Data to fix
+     * @param  mixed  $input Data to fix
      * @return mixed  Properly UTF-8 encoded data
      * @access public
      */
@@ -606,7 +612,7 @@
     /**
      * Decodes encoded UTF-8 string/object/array (recursive)
      *
-     * @param  mixed  Input data
+     * @param  mixed $input Input data
      * @return mixed  Decoded data
      * @access public
      */
@@ -630,7 +636,7 @@
     /**
      * Adds a query result and returns a handle ID
      *
-     * @param  object  Query handle
+     * @param  object $res Query handle
      * @return mixed   Handle ID
      * @access private
      */
@@ -641,12 +647,12 @@
             $this->db_error = true;
             $this->db_error_msg = $res->getMessage();
             raise_error(array('code' => 500, 'type' => 'db',
-    	        'line' => __LINE__, 'file' => __FILE__,
-    	        'message' => $res->getMessage() . " Query: " 
-	            . substr(preg_replace('/[\r\n]+\s*/', ' ', $res->userinfo), 0, 512)),
-	            true, false);
+                'line' => __LINE__, 'file' => __FILE__,
+                'message' => $res->getMessage() . " Query: " 
+                . substr(preg_replace('/[\r\n]+\s*/', ' ', $res->userinfo), 0, 512)),
+                true, false);
         }
-    
+
         $res_id = sizeof($this->a_query_results);
         $this->last_res_id = $res_id;
         $this->a_query_results[$res_id] = $res;
@@ -658,7 +664,7 @@
      * Resolves a given handle ID and returns the according query handle
      * If no ID is specified, the last resource handle will be returned
      *
-     * @param  number  Handle ID
+     * @param  number $res_id Handle ID
      * @return mixed   Resource handle or false on failure
      * @access private
      */
@@ -670,7 +676,7 @@
         if (isset($this->a_query_results[$res_id]))
             if (!PEAR::isError($this->a_query_results[$res_id]))
                 return $this->a_query_results[$res_id];
-    
+
         return false;
     }
 
@@ -678,8 +684,8 @@
     /**
      * Create a sqlite database from a file
      *
-     * @param  object  SQLite database handle
-     * @param  string  File path to use for DB creation
+     * @param  MDB2   $dbh       SQLite database handle
+     * @param  string $file_name File path to use for DB creation
      * @access private
      */
     private function _sqlite_create_database($dbh, $file_name)
@@ -692,7 +698,7 @@
         if (strlen($data))
             if (!sqlite_exec($dbh->connection, $data, $error) || MDB2::isError($dbh)) 
                 raise_error(array('code' => 500, 'type' => 'db',
-	                'line' => __LINE__, 'file' => __FILE__,
+                    'line' => __LINE__, 'file' => __FILE__,
                     'message' => $error), true, false); 
     }
 
@@ -725,7 +731,9 @@
 function mdb2_debug_handler(&$db, $scope, $message, $context = array())
 {
     if ($scope != 'prepare') {
-        $debug_output = $scope . '('.$db->db_index.'): ' . $message;
+        $debug_output = sprintf('%s(%d): %s;',
+            $scope, $db->db_index, rtrim($message, ';'));
         write_log('sql', $debug_output);
     }
 }
+
@@ -229,10 +231,10 @@
      * Execute a SQL query with limits
      *
-     * @param  string  SQL query to execute
-     * @param  number  Offset for LIMIT statement
-     * @param  number  Number of rows for LIMIT statement
-     * @param  array   Values to be inserted in query
+     * @param  string $query   SQL query to execute
+     * @param  number $offset  Offset for LIMIT statement
+     * @param  number $numrows Number of rows for LIMIT statement
+     * @param  array  $params  Values to be inserted in query
      * @return number  Query handle identifier
      * @access private

--
Gitblit v1.9.1